.. :changelog:

History
-------

0.2.0 (2017-09-28)
++++++++++++++++++
* adaption to work with Python 3

0.1.0dev (2014-07-22)
+++++++++++++++++++++
* Consistent time recording
* Syntactic sugar for Workflowmgr calls
* Parallel execution of worklows on IPython clusters

0.1.0 (2014-01-01)
++++++++++++++++++

* First release on PyPI.
